@@ -26,7 +26,7 @@ use warnings;
 
 package CAD::Firemen::Analyze;
 {
-  $CAD::Firemen::Analyze::VERSION = '0.7.0';
+  $CAD::Firemen::Analyze::VERSION = '0.7.1';
 }
 use Exporter 'import';
 our @EXPORT_OK = qw(compare checkConfig checkTreeConfig optionsToIngoreAtPathCheckings);
@@ -561,7 +561,7 @@ CAD::Firemen::Analyze - Module provides functions to compare to lists with optio
 
 =head1 VERSION
 
-version 0.7.0
+version 0.7.1
 
 =head1 METHODS
 
@@ -574,10 +574,10 @@ The added and removed list of options is an array, which contains the option nam
 The list of changed options is a hash with the option names as keys and references to the related
 CAD::Firemen::Change object as values.
 
-# the keys of %{$added} and %{$removed} are line numbers of the second options
+# the keys of %{$added} and %{$removed} are the option names of the second options
 $added = {
-  1 => "ADDED_OPTION_ONE",
-  2 => "ADDED_OPTION_TWO",
+  "ADDED_OPTION_ONE" => FIRST_LINE_NUMBER,
+  "ADDED_OPTION_TWO" => FIRST_LINE_NUMBER
 };
 
 $changed {
@@ -587,11 +587,11 @@ $changed {
   ];
 };
 
-# the keys of %{$removed} are line numbers of the second options
+# the keys of %{$removed} are the option names of the second options
 $removed = {
-  4 => "REMOVED_OPTION_ONE",
-  5 => "REMOVED_OPTION_TWO",
-  6 => "REMOVED_OPTION_ONE"
+  "REMOVED_OPTION_ONE" => FIRST_LINE_NUMBER,
+  "REMOVED_OPTION_TWO" => FIRST_LINE_NUMBER,
+  "REMOVED_OPTION_ONE" => FIRST_LINE_NUMBER
 };
 
 =head2 optionsToIngoreAtPathCheckings
